@@ -58,6 +58,13 @@ caption_default_docx_openxml <- function(x, keep_with_next = FALSE,
   x <- process_caption_fp_par(x, keep_with_next = keep_with_next)
   if (!is.null(x$caption$fp_p)) {
     p_pr <- format(x$caption$fp_p, type = "wml")
+    if (packageVersion("officer") > numeric_version("0.6.8")) {
+      m <- regexpr("w:pstlname=\"[^\"]+\"", p_pr);
+      pstlname <- regmatches(x = p_pr, m)
+      style_name <- gsub("(w:pstlname=)(\")([^\"]+)(\")", "\\3", pstlname)
+      style_id <- gsub("[^a-zA-Z0-9]", "", style_name)
+      p_pr <- gsub(pstlname, sprintf("w:val=\"%s\"", style_id), p_pr, fixed = TRUE)
+    }
   } else {
     cap_style_id <- gsub("[^a-zA-Z0-9]", "", x$caption$word_stylename)
     p_pr <- paste0(
@@ -145,7 +152,7 @@ caption_bookdown_html <- function(x) {
 
   reference_label <- ""
   if (!is.null(x$caption$autonum$bookmark)) {
-    reference_label <- paste0("(\\#", x$caption$autonum$seq_id, ":", x$caption$autonum$bookmark, ")")
+    reference_label <- paste0("(#", x$caption$autonum$seq_id, ":", x$caption$autonum$bookmark, ")")
   }
 
   if (!is.null(x$caption$fp_p)) {
@@ -167,12 +174,11 @@ caption_bookdown_html <- function(x) {
   caption_chunks_str <- html_caption$html
   css <- html_caption$css
   caption_str <- paste0(
-    sprintf("<caption%s%s>", inline_css, caption_class),
+    sprintf("\n<caption%s%s>", inline_css, caption_class),
     reference_label,
     caption_chunks_str,
-    "</caption>"
+    "</caption>\n"
   )
-  caption_str <- with_html_unquotes(caption_str)
 
   attr(caption_str, "css") <- css
   caption_str
@@ -269,7 +275,7 @@ has_caption <- function(x) {
 
 has_autonum <- function(x) {
   has_it <- FALSE
-  if (!is.null(x$caption$autonum$bookmark)) {
+  if (!is.null(x$caption$autonum)) {
     has_it <- TRUE
   }
   has_it
