@@ -10,6 +10,33 @@ pml_spans <- function(value) {
   )
   span_data
 }
+default_fp_text_pml <- function(value) {
+  default_chunks_properties <- information_data_default_chunk(value)
+  unique_text_props <- distinct_text_properties(default_chunks_properties)
+  rpr <- sapply(
+    split(unique_text_props[setdiff(colnames(unique_text_props), "classname")], unique_text_props$classname),
+    function(x) {
+      z <- do.call(officer::fp_text_lite, x)
+      val <- format(z, type = "pml")
+      val <- gsub("<a:rPr", "<a:endParaRPr", val, fixed = TRUE)
+      val <- gsub("</a:rPr>", "</a:endParaRPr>", val, fixed = TRUE)
+      val
+    }
+  )
+
+  unique_text_props$fp_txt_default <- unname(rpr[unique_text_props$classname])
+  setDT(default_chunks_properties)
+  default_chunks_properties <- merge(
+    default_chunks_properties, unique_text_props,
+    by = c("color", "font.size", "bold", "italic", "underlined", "font.family",
+           "hansi.family", "eastasia.family", "cs.family", "vertical.align",
+           "shading.color")
+  )
+  setDF(default_chunks_properties)
+  default_chunks_properties <- default_chunks_properties[, c(".part", ".row_id", ".col_id", "fp_txt_default")]
+  default_chunks_properties
+}
+
 
 #' @importFrom data.table shift
 pml_cells <- function(value, cell_data) {
@@ -20,12 +47,12 @@ pml_cells <- function(value, cell_data) {
   cell_data$width <- NULL # need to get rid of originals that are empty, should probably rm them
   cell_data$height <- NULL
   cell_data$hrule <- NULL
-  cell_data <- merge(cell_data, cell_widths, by = "col_id")
-  cell_data <- merge(cell_data, cell_heights, by = c(".part", "ft_row_id"))
-  cell_data <- merge(cell_data, cell_hrule, by = c(".part", "ft_row_id"))
+  cell_data <- merge(cell_data, cell_widths, by = ".col_id")
+  cell_data <- merge(cell_data, cell_heights, by = c(".part", ".row_id"))
+  cell_data <- merge(cell_data, cell_hrule, by = c(".part", ".row_id"))
 
   setDT(cell_data)
-  setorderv(cell_data, cols = c(".part", "ft_row_id", "col_id"))
+  setorderv(cell_data, cols = c(".part", ".row_id", ".col_id"))
 
   data_ref_cells <- distinct_cells_properties(cell_data)
 
@@ -76,14 +103,14 @@ pml_cells <- function(value, cell_data) {
   # organise everything
   cell_data <- merge(cell_data, data_ref_cells, by = intersect(colnames(cell_data), colnames(data_ref_cells)))
   cell_data <- merge(cell_data, style_dat, by = "classname")
-  cell_data <- cell_data[, .SD, .SDcols = c(".part", "ft_row_id", "col_id", "fp_cell_pml")]
+  cell_data <- cell_data[, .SD, .SDcols = c(".part", ".row_id", ".col_id", "fp_cell_pml")]
   setDF(cell_data)
   cell_data
 }
 
 gen_raw_pml <- function(value, uid = 99999L, offx = 0, offy = 0, cx = 0, cy = 0) {
-  cell_attributes <- fortify_cells_properties(value)
-  par_attributes <- fortify_paragraphs_properties(value)
+  cell_attributes <- information_data_cell(value)
+  par_attributes <- information_data_paragraph(value)
 
   # cell_attributes and par_attributes must be ordered identically
   new_pos <- ooxml_rotation_alignments(
@@ -98,8 +125,8 @@ gen_raw_pml <- function(value, uid = 99999L, offx = 0, offy = 0, cx = 0, cy = 0)
   setDT(cell_attributes)
   cell_attributes <- merge(
     cell_attributes,
-    par_attributes[, c(".part", "ft_row_id", "col_id", "padding.bottom", "padding.top")],
-    by = c(".part", "ft_row_id", "col_id")
+    par_attributes[, c(".part", ".row_id", ".col_id", "padding.bottom", "padding.top")],
+    by = c(".part", ".row_id", ".col_id")
   )
   cell_attributes[, c("margin.bottom", "margin.top") :=
     list(
@@ -114,13 +141,22 @@ gen_raw_pml <- function(value, uid = 99999L, offx = 0, offy = 0, cx = 0, cy = 0)
   cell_data <- pml_cells(value, cell_attributes)
   cell_heights <- fortify_height(value)
 
+  default_chunks_properties <- default_fp_text_pml(value)
+
   setDT(cell_data)
 
-  tab_data <- merge(cell_data, par_data, by = c(".part", "ft_row_id", "col_id"))
-  tab_data <- merge(tab_data, txt_data, by = c(".part", "ft_row_id", "col_id"))
-  tab_data <- merge(tab_data, span_data, by = c(".part", "ft_row_id", "col_id"))
-  tab_data$col_id <- factor(tab_data$col_id, levels = value$col_keys)
-  setorderv(tab_data, cols = c(".part", "ft_row_id", "col_id"))
+  tab_data <- merge(cell_data, par_data, by = c(".part", ".row_id", ".col_id"))
+  tab_data <- merge(tab_data, default_chunks_properties, by = c(".part", ".row_id", ".col_id"))
+  tab_data <- merge(tab_data, txt_data, by = c(".part", ".row_id", ".col_id"))
+
+  tab_data[tab_data$is_empty %in% TRUE, c("fp_par_xml") := list(
+    paste0(.SD$fp_par_xml, .SD$fp_txt_default)
+  )]
+  tab_data[, c("fp_txt_default", "is_empty") := list(NULL, NULL)]
+
+  tab_data <- merge(tab_data, span_data, by = c(".part", ".row_id", ".col_id"))
+  tab_data$.col_id <- factor(tab_data$.col_id, levels = value$col_keys)
+  setorderv(tab_data, cols = c(".part", ".row_id", ".col_id"))
 
   tab_data[, c("pml") := list(
     paste0(
@@ -140,11 +176,11 @@ gen_raw_pml <- function(value, uid = 99999L, offx = 0, offy = 0, cx = 0, cy = 0)
   )]
   tab_data[, c("fp_cell_pml", "grid_span", "row_span") := list(NULL, NULL, NULL)]
 
-  cells <- dcast(tab_data, .part + ft_row_id ~ col_id, drop = TRUE, fill = "", value.var = "pml", fun.aggregate = I)
-  cells <- merge(cells, cell_heights, by = c(".part", "ft_row_id"))
+  cells <- dcast(tab_data, .part + .row_id ~ .col_id, drop = TRUE, fill = "", value.var = "pml", fun.aggregate = I)
+  cells <- merge(cells, cell_heights, by = c(".part", ".row_id"))
 
   rowheights <- cells$height
-  cells[, c("ft_row_id", "height", ".part") := list(NULL, NULL, NULL)]
+  cells[, c(".row_id", "height", ".part") := list(NULL, NULL, NULL)]
   rows <- apply(as.matrix(cells), 1, paste0, collapse = "")
   rows <- sprintf("<a:tr h=\"%.0f\">%s</a:tr>", rowheights * 914400, rows)
   rows <- paste0(rows, collapse = "")
