@@ -427,7 +427,7 @@ knit_to_pml <- function(x) {
 #' @param align left, center (default) or right. Only for docx/html/pdf.
 #' @param ... arguments for 'pdf_document' call when preview is "pdf".
 #' @family flextable print function
-#' @importFrom utils browseURL
+#' @importFrom utils browseURL str
 #' @importFrom rmarkdown render pdf_document
 #' @importFrom officer read_pptx add_slide read_docx
 print.flextable <- function(x, preview = "html", align = "center", ...) {
@@ -439,7 +439,7 @@ print.flextable <- function(x, preview = "html", align = "center", ...) {
     cat("header has", nrow(x$header$dataset), "row(s)", "\n")
     cat("body has", nrow(x$body$dataset), "row(s)", "\n")
     cat("original dataset sample:", "\n")
-    print(x$body$dataset[seq_len(min(c(5, nrow(x$body$dataset)))), ])
+    str(x$body$dataset)
   } else if (preview == "html") {
     print(browsable(htmltools_value(x = x, ft.align = align)))
   } else if (preview == "pptx") {
@@ -809,7 +809,7 @@ save_as_pptx <- function(..., values = NULL, path) {
   show_names <- !is.null(titles)
   z <- read_pptx()
   for (i in seq_along(values)) {
-    z <- add_slide(z)
+    z <- add_slide(z, "Title and Content")
     if (show_names) {
       z <- ph_with(z, titles[i], location = ph_location_type(type = "title"))
     }
@@ -871,9 +871,7 @@ save_as_docx <- function(..., values = NULL, path, pr_section = NULL, align = "c
 
   if (is.null(pr_section)) {
     pr_section <- prop_section(
-      page_size = page_size(orient = "portrait", width = 8.3, height = 11.7),
-      type = "continuous",
-      page_margins = page_mar()
+      type = "continuous"
     )
   }
 
@@ -948,9 +946,7 @@ save_as_rtf <- function(..., values = NULL, path, pr_section = NULL) {
   show_names <- !is.null(titles)
   if (is.null(pr_section)) {
     pr_section <- prop_section(
-      page_size = page_size(orient = "portrait", width = 8.3, height = 11.7),
-      type = "continuous",
-      page_margins = page_mar()
+      type = "continuous"
     )
   }
 
@@ -1096,43 +1092,6 @@ plot.flextable <- function(x, ...) {
   invisible()
 }
 
-#' @export
-#' @title Transform a flextable into a raster
-#' @description save a flextable as an image and return the corresponding
-#' raster. This function has been implemented to let flextable be printed
-#' on a ggplot object.
-#'
-#' The function is no longer very useful since [gen_grob()] exists and
-#' will be deprecated in a future version.
-#' @note This function requires package 'magick'.
-#' @param x a flextable object
-#' @param ... additional arguments passed to other functions
-#' @importFrom grDevices as.raster
-#' @examples
-#' ft <- qflextable(head(mtcars))
-#' \dontrun{
-#' if (require("ggplot2") && require("magick")) {
-#'   print(qplot(speed, dist, data = cars, geom = "point"))
-#'   grid::grid.raster(as_raster(ft))
-#' }
-#' }
-#' @family flextable print function
-#' @keywords internal
-as_raster <- function(x, ...) {
-  .Deprecated(new = "gen_grob()")
-  if (!requireNamespace("magick", quietly = TRUE)) {
-    stop(sprintf(
-      "'%s' package should be installed to create an image from a flextable.",
-      "magick"
-    ))
-  }
-  path <- tempfile(fileext = ".png")
-  on.exit(unlink(path))
-  save_as_image(x, path, expand = 0)
-  img <- magick::image_read(path = path)
-  as.raster(img, ...)
-}
-
 
 # utils ----
 is_in_bookdown <- function() {
